==> haskell-hslua-list-1.1.3-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-list
version:              1.1.3
visibility:           public
id:                   hslua-list-1.1.3-I4vbVRTfie29WnKNxkL68S
key:                  hslua-list-1.1.3-I4vbVRTfie29WnKNxkL68S
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Opinionated, but extensible Lua list type.
description:          List type for Lua, with a Haskell interface.
category:             Foreign
abi:                  1edf86d02b311a0a648420db7dc97d61
exposed:              True
exposed-modules:      HsLua.List
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-list
hs-libraries:         HShslua-list-1.1.3-I4vbVRTfie29WnKNxkL68S
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-CKGOwykRACQ9obLmdILpjy

haddock-interfaces:   /usr/share/doc/haskell-hslua-list/html/hslua-list.haddock
haddock-html:         /usr/share/doc/haskell-hslua-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-list-1.1.3-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-list
version:              1.1.3
visibility:           public
id:                   hslua-list-1.1.3-IVs8v9xNBXb5RrtjYQ9xUi
key:                  hslua-list-1.1.3-IVs8v9xNBXb5RrtjYQ9xUi
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Opinionated, but extensible Lua list type.
description:          List type for Lua, with a Haskell interface.
category:             Foreign
abi:                  5503170460d89c1aa416eab37e9a5762
exposed:              True
exposed-modules:      HsLua.List
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-list-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-list
hs-libraries:         HShslua-list-1.1.3-IVs8v9xNBXb5RrtjYQ9xUi
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hslua-core-2.3.1-7STvIGdLdk7H2ZozH0ALPf

haddock-interfaces:   /usr/share/doc/haskell-hslua-list/html/hslua-list.haddock
haddock-html:         /usr/share/doc/haskell-hslua-list/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
